@@ -374,6 +374,7 @@ static int32_t get_nvars(const char *fn)
 {
     FILE * fh = fopen(fn, "r");
     char * line = NULL;
+    char * line2 = NULL;
     size_t len;
     nvars_t nvars = -1; 
 
@@ -381,17 +382,18 @@ static int32_t get_nvars(const char *fn)
     if (getline(&line, &len, fh) != -1)
     {
         nvars = 1;
-        line = strchr(line, ',');
-        while (line != NULL)
+        line2 = strchr(line, ',');
+        while (line2 != NULL)
         {
             nvars++;
             // line points to a comma, which must be followed by one or more characters
             // --> line+1 is valid
-            line = strchr(line+1, ',');
+            line2 = strchr(line2+1, ',');
         }
     }
 
     free(line);
+    free(line2);
     fclose(fh);
 
     return nvars;
@@ -606,11 +608,11 @@ static void remove_trailing_delim(char *line, size_t *len, char delim) {
     }
 }
 
-static void get_nterms_and_all_nterms(FILE *fh, char **linep,
+static void get_nterms_and_all_nterms(FILE *fh, 
                                       int max_line_size, data_gens_ff_t *gens,
                                       int32_t *nr_gens, nelts_t *nterms, nelts_t *all_nterms){
 
-    char *line  = *linep;
+    char *line  = NULL; 
     size_t len = 0;
     ssize_t nread;
     for (int32_t i = 0; i < *nr_gens; i++) {
@@ -626,7 +628,7 @@ static void get_nterms_and_all_nterms(FILE *fh, char **linep,
         gens->lens[i] = *nterms;
         *all_nterms += *nterms;
     }
-    *linep  = line;
+    free(line);
     gens->nterms = *all_nterms;
 }
 
@@ -861,13 +863,13 @@ static int get_coefficient_mpz_and_term_from_line(char *line, int32_t nterms,
   return 1;
 }
 
-static void get_coeffs_and_exponents_ff32(FILE *fh, char **linep, nelts_t all_nterms,
+static void get_coeffs_and_exponents_ff32(FILE *fh, nelts_t all_nterms,
         int32_t *nr_gens, data_gens_ff_t *gens){
     int32_t pos = 0;
     size_t len = 0;
     ssize_t nread;
 
-    char *line  = *linep;
+    char *line  = NULL; 
     if(getline(&line, &len, fh) !=-1){
     }
     if(getline(&line, &len, fh) !=-1){
@@ -893,17 +895,17 @@ static void get_coeffs_and_exponents_ff32(FILE *fh, char **linep, nelts_t all_nt
         }
         pos += gens->lens[i];
     }
-    *linep  = line;
+    free(line);
 }
 
 
-static void get_coeffs_and_exponents_mpz(FILE *fh, char **linep, nelts_t all_nterms,
+static void get_coeffs_and_exponents_mpz(FILE *fh, nelts_t all_nterms,
         int32_t *nr_gens, data_gens_ff_t *gens){
     int32_t pos = 0;
     size_t len = 0;
     ssize_t nread;
 
-    char *line  = *linep;
+    char *line  = NULL; 
     if(getline(&line, &len, fh) !=-1){
     }
     if(getline(&line, &len, fh) !=-1){
@@ -936,7 +938,7 @@ static void get_coeffs_and_exponents_mpz(FILE *fh, char **linep, nelts_t all_nte
         }
         pos += 2 * gens->lens[i];
     }
-    *linep  = line;
+    free(line);
 }
 
 
@@ -987,6 +989,9 @@ static inline void get_data_from_file(char *fn, int32_t *nr_vars,
   char **vnames = (char **)malloc((*nr_vars) * sizeof(char *));
   get_variables(fh, line, max_line_size, nr_vars, gens, vnames);
   if (duplicate_vnames(vnames, *nr_vars) == 1) {
+      for(int32_t i = 0; i < *nr_vars; i++){
+          free(vnames[i]);
+      }
       free(vnames);
       free(line);
       exit(1);
@@ -996,17 +1001,17 @@ static inline void get_data_from_file(char *fn, int32_t *nr_vars,
   initialize_data_gens(*nr_vars, *nr_gens, *field_char, gens);
 
   nelts_t nterms, all_nterms = 0;
-  get_nterms_and_all_nterms(fh, &line, max_line_size, gens, nr_gens,
+  get_nterms_and_all_nterms(fh, max_line_size, gens, nr_gens,
                             &nterms, &all_nterms);
 
   fclose(fh);
   fh = fopen(fn, "r");
 
   if(gens->field_char){
-    get_coeffs_and_exponents_ff32(fh, &line, all_nterms, nr_gens, gens);
+    get_coeffs_and_exponents_ff32(fh, all_nterms, nr_gens, gens);
   }
   else{
-    get_coeffs_and_exponents_mpz(fh, &line, all_nterms, nr_gens, gens);
+    get_coeffs_and_exponents_mpz(fh, all_nterms, nr_gens, gens);
   }
 
   free(line);
