@@ -1046,6 +1046,8 @@ static inline void free_heap_flags(usolve_flags *flags,
       mpz_clear(flags->tmpol_desc[i]);
       mpz_clear(flags->tmpol[i]);
     }
+    free(flags->tmpol);
+    free(flags->tmpol_desc);
     mpz_clear(flags->Values[0]);
     mpz_clear(flags->Values[1]);
     free(flags->Values);
@@ -1307,8 +1309,6 @@ interval *real_roots(mpz_t *upoly, unsigned long deg,
     }
   }
 
-  /* display_roots_system(stderr, roots, nbroots); */
-  /* fprintf(stderr, "First root \n"); */
   /* display_root(stderr, roots); */
 
   e_time = realtime ( ) - e_time;
